@@ -92,7 +92,7 @@ setMethod("plot", "dtiTensor", function(x, y, slice=1, view="axial", quant=0, mi
                 fa=double(n1*n2),
                 md=double(n1*n2),
                 andir=double(3*n1*n2),
-                DUPL=FALSE,
+                DUP=FALSE,
                 PACKAGE="dti")[c("fa","md","andir")]
   } else {
   z <- .Fortran("dti2Dfa",
@@ -103,7 +103,7 @@ setMethod("plot", "dtiTensor", function(x, y, slice=1, view="axial", quant=0, mi
                 fa=double(n1*n2),
                 md=double(n1*n2),
                 andir=double(3*n1*n2),
-                DUPL=FALSE,
+                DUP=FALSE,
                 PACKAGE="dti")[c("fa","md","andir")]
    }
    oldpar <- par(mfrow=c(3,3),mar=mar,mgp=mgp,...)
